@@ -31,25 +31,24 @@ __all__ = [
     "recreate_expression",
 ]
 
+from modelparameters.codegeneration import latex, sympycode
+from modelparameters.logger import error
+
 # ModelParameters imports
 from modelparameters.parameters import SlaveParam
 from modelparameters.sympytools import sp
-from modelparameters.codegeneration import sympycode, latex
-from sympy.core.function import AppliedUndef
+from modelparameters.utils import check_arg, scalars
 
-# Local imports
-from gotran.common import (
-    error,
-    check_arg,
-    scalars,
-    debug,
-    DEBUG,
-    get_log_level,
-    Timer,
-    tuplewrap,
-    parameters,
+from .odeobjects import (
+    IndexedObject,
+    ODEValueObject,
+    ParameterIndexedObject,
+    State,
+    StateIndexedObject,
+    Time,
+    cmp,
+    cmp_to_key,
 )
-from gotran.model.odeobjects import *
 
 
 def recreate_expression(expr, *replace_dicts, **kwargs):
@@ -58,10 +57,10 @@ def recreate_expression(expr, *replace_dicts, **kwargs):
     """
 
     replace_type = kwargs.get("replace_type", "xreplace")
-    if not replace_type in ["xreplace", "subs"]:
+    if replace_type not in ["xreplace", "subs"]:
         error(
             "Valid alternatives for replace_type is: 'xreplace', "
-            "'subs' got {0}".format(replace_type)
+            "'subs' got {0}".format(replace_type),
         )
 
     # First do the replacements
@@ -172,7 +171,7 @@ class Expression(ODEValueObject):
 
         if not symbols_from_expr(expr, include_numbers=True):
             error(
-                "expected the expression to contain at least one " "Symbol or Number."
+                "expected the expression to contain at least one " "Symbol or Number.",
             )
 
         # Call super class with expression as the "value"
@@ -183,7 +182,7 @@ class Expression(ODEValueObject):
             sorted(
                 symbols_from_expr(expr),
                 key=cmp_to_key(lambda a, b: cmp(sympycode(a), sympycode(b))),
-            )
+            ),
         )
 
         if dependent:
@@ -211,8 +210,7 @@ class Expression(ODEValueObject):
 
     @property
     def sym(self):
-        """
-        """
+        """"""
         return self._sym
 
     def replace_expr(self, *replace_dicts):
@@ -235,20 +233,20 @@ class Expression(ODEValueObject):
         """
         Return a formatted str of __init__ arguments
         """
-        return "'{0}', {1}".format(self.name, sympycode(self.expr))
+        return f"'{self.name}', {sympycode(self.expr)}"
 
     def _repr_latex_(self):
         """
         Return a pretty latex representation of the Expression object
         """
 
-        return "${0} = {1}$".format(self._repr_latex_name(), self._repr_latex_expr())
+        return f"${self._repr_latex_name()} = {self._repr_latex_expr()}$"
 
     def _repr_latex_expr(self):
         return latex(self.expr)
 
     def _repr_latex_name(self):
-        return "{0}".format(latex(self.name))
+        return f"{latex(self.name)}"
 
 
 class Intermediate(Expression):
@@ -308,7 +306,7 @@ class StateSolution(Intermediate):
         """
         Return a formatted str of __init__ arguments
         """
-        return "'{0}', {1}".format(repr(self.state), sympycode(self.expr))
+        return f"'{repr(self.state)}', {sympycode(self.expr)}"
 
 
 class DerivativeExpression(Intermediate):
@@ -339,7 +337,7 @@ class DerivativeExpression(Intermediate):
         if dep_var.sym not in der_expr.sym.args:
             error(
                 "Cannot create a DerivativeExpression as {0} is not "
-                "dependent on {1}".format(der_expr, dep_var)
+                "dependent on {1}".format(der_expr, dep_var),
             )
 
         der_sym = sp.Derivative(der_expr.sym, dep_var.sym)
@@ -366,13 +364,12 @@ class DerivativeExpression(Intermediate):
         """
         Return a formatted str of __init__ arguments
         """
-        return "{0}, {1}, {2}".format(
-            repr(self._der_expr), repr(self._dep_var), sympycode(self.expr)
-        )
+        return f"{repr(self._der_expr)}, {repr(self._dep_var)}, {sympycode(self.expr)}"
 
     def _repr_latex_name(self):
         return "\\frac{{d{0}}}{{d{1}}}".format(
-            latex(self._der_expr.name), latex(self._dep_var.name)
+            latex(self._der_expr.name),
+            latex(self._dep_var.name),
         )
 
 
@@ -387,7 +384,9 @@ class RateExpression(Intermediate):
         check_arg(from_state, (State, StateSolution), 1, RateExpression)
 
         super(RateExpression, self).__init__(
-            "rates_{0}_{1}".format(to_state, from_state), expr, dependent
+            f"rates_{to_state}_{from_state}",
+            expr,
+            dependent,
         )
         self._to_state = to_state
         self._from_state = from_state
@@ -397,7 +396,9 @@ class RateExpression(Intermediate):
         Return a formatted str of __init__ arguments
         """
         return "{0}, {1}, {2}".format(
-            repr(self._to_state), repr(self._from_state), sympycode(self.expr)
+            repr(self._to_state),
+            repr(self._from_state),
+            sympycode(self.expr),
         )
 
     @property
@@ -445,7 +446,7 @@ class StateExpression(Expression):
         """
         Return a formatted str of __init__ arguments
         """
-        return "'{0}', {1}, {2}".format(self.name, repr(state), sympycode(self.expr))
+        return f"'{self.name}', {repr(self.state)}, {sympycode(self.expr)}"
 
 
 class StateDerivative(StateExpression):
@@ -488,10 +489,10 @@ class StateDerivative(StateExpression):
         """
         Return a formatted str of __init__ arguments
         """
-        return "{0}, {1}".format(repr(self._state), sympycode(self.expr))
+        return f"{repr(self._state)}, {sympycode(self.expr)}"
 
     def _repr_latex_name(self):
-        return "\\frac{{d{0}}}{{dt}}".format(latex(self.state.name))
+        return f"\\frac{{d{latex(self.state.name)}}}{{dt}}"
 
 
 class AlgebraicExpression(StateExpression):
@@ -517,7 +518,10 @@ class AlgebraicExpression(StateExpression):
         check_arg(state, State, 0, AlgebraicExpression)
 
         super(AlgebraicExpression, self).__init__(
-            "alg_{0}_0".format(state), state, expr, dependent
+            f"alg_{state}_0",
+            state,
+            expr,
+            dependent,
         )
 
         # Check that the expr is dependent on the state
@@ -530,7 +534,7 @@ class AlgebraicExpression(StateExpression):
         """
         Return a formatted str of __init__ arguments
         """
-        return "{0}, {1}".format(repr(self._state), sympycode(self.expr))
+        return f"{repr(self._state)}, {sympycode(self.expr)}"
 
     def _repr_latex_name(self):
         return "0"
@@ -578,7 +582,14 @@ class IndexedExpression(IndexedObject, Expression):
             String that can be used for enumeration
         """
         IndexedObject.__init__(
-            self, basename, indices, shape, array_params, add_offset, dependent, enum
+            self,
+            basename,
+            indices,
+            shape,
+            array_params,
+            add_offset,
+            dependent,
+            enum,
         )
         Expression.__init__(self, self.name, expr, dependent)
 
@@ -627,7 +638,14 @@ class StateIndexedExpression(StateIndexedObject, Expression):
         """
 
         StateIndexedObject.__init__(
-            self, basename, indices, state, shape, array_params, add_offset, dependent
+            self,
+            basename,
+            indices,
+            state,
+            shape,
+            array_params,
+            add_offset,
+            dependent,
         )
         Expression.__init__(self, self.name, expr, dependent)
 
